#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import sys
import os

project = 'dex'
master_doc = 'dex'
source_suffix = '.rst'

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    ('dex', 'dex', 'DesktopEntry Execution',
     ['Jan Christoph Ebersbach', u'Johannes Löthberg'], 1)
]
